# we build CUPS also with relro
%global _hardened_build 0

%define libname %mklibname %name 1
%define develname %mklibname -d %name

Summary: OpenPrinting CUPS filters and backends
Name:    cups-filters
Version: 1.0.53
%define subrel 2
Release: %mkrel 1
# For a breakdown of the licensing, see COPYING file
# GPLv2:   filters: commandto*, imagetoraster, pdftops, rasterto*,
#                   imagetopdf, pstopdf, texttopdf
#         backends: parallel, serial
# GPLv2+:  filters: gstopxl, textonly, texttops, imagetops
# GPLv3:   filters: bannertopdf
# GPLv3+:  filters: urftopdf
# LGPLv2+:   utils: cups-browsed
# MIT:     filters: gstoraster, pdftoijs, pdftoopvp, pdftopdf, pdftoraster
License: GPLv2 and GPLv2+ and GPLv3 and GPLv3+ and LGPLv2+ and MIT

Group:   System/Printing
Url:     http://www.linuxfoundation.org/collaborate/workgroups/openprinting/cups-filters
Source0: http://www.openprinting.org/download/cups-filters/cups-filters-%{version}.tar.xz
Source1: cups-browsed.service

# Fedora patches:
# Fix PDF landscape printing (bug #768811).
Patch1: cups-filters-pdf-landscape.patch

Patch2: cups-filters-remove-bad-chars.patch

Patch3: cups-filters-1.0.69-CVE-2015-3258.patch
Patch4: cups-filters-1.0.70-CVE-2015-3279.patch

Requires: %{libname} = %{version}-%{release}

Obsoletes: php-cups

BuildRequires: cups-devel
BuildRequires: pkgconfig(ijs)
# pdftopdf
BuildRequires: pkgconfig(libqpdf)
# pdftops
BuildRequires: poppler
# pdftoijs, pdftoopvp, pdftoraster
BuildRequires: poppler-devel poppler-cpp-devel
BuildRequires: libjpeg-devel
BuildRequires: libpng-devel
BuildRequires: libtiff-devel
BuildRequires: zlib-devel
# libijs
BuildRequires: ghostscript-devel
BuildRequires: freetype-devel
BuildRequires: fontconfig-devel
BuildRequires: lcms2-devel
# cups-browsed
BuildRequires: avahi-core-devel avahi-glib-devel
BuildRequires: systemd

# Make sure we get postscriptdriver tags.
BuildRequires: python-cups

# Testing font for test scripts.
BuildRequires: fonts-ttf-dejavu

# autogen.sh
BuildRequires: autoconf
BuildRequires: automake
BuildRequires: libtool
# configure needs /bin/gs (mga#11684):
BuildRequires: ghostscript

Requires: cups-filesystem
Requires: poppler
# texttopdf
Requires: fonts-ttf-liberation
# pstopdf
Requires: bc
Conflicts: cups < 1.6.2-3
Conflicts: ghostscript-common < 9.09

# cups-browsed
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

%package -n %libname
Summary: OpenPrinting CUPS filters and backends - cupsfilters and fontembed libraries
Group:   System/Libraries
# LGPLv2: libcupsfilters
# MIT:    libfontembed
License: LGPLv2 and MIT

%package -n %develname
Summary: OpenPrinting CUPS filters and backends - development environment
Group:   Development/C
License: LGPLv2 and MIT
Requires: %{libname} = %{version}-%{release}
Provides: %{name}-devel = %{version}-%{release}

%description
Contains backends, filters, and other software that was
once part of the core CUPS distribution but is no longer maintained by
Apple Inc. In addition it contains additional filters developed
independently of Apple, especially filters for the PDF-centric printing
workflow introduced by OpenPrinting.

%description -n %libname
This package provides cupsfilters and fontembed libraries.

%description -n %develname
This is the development package for OpenPrinting CUPS filters and backends.

%prep
%setup -q
%patch1 -p1
%patch2 -p1
%patch3 -p0
%patch4 -p0

%build
# work-around Rpath
./autogen.sh

# --with-pdftops=hybrid - use Poppler's pdftops instead of Ghostscript for
#                         Brother, Minolta, and Konica Minolta to work around
#                         bugs in the printer's PS interpreters
# --with-rcdir=no - don't install SysV init script
%configure2_5x --disable-static \
           --disable-silent-rules \
           --with-pdftops=hybrid \
           --enable-dbus \
           --with-rcdir=no

%make

%install
%makeinstall_std

# https://fedoraproject.org/wiki/Packaging_tricks#With_.25doc
mkdir __doc
mv  %{buildroot}%{_datadir}/doc/cups-filters/* __doc
rm -rf %{buildroot}%{_datadir}/doc/cups-filters

# Don't ship libtool la files.
rm -f %{buildroot}%{_libdir}/lib*.la

# Not sure what is this good for.
rm -f %{buildroot}%{_bindir}/ttfread

# systemd unit file
mkdir -p %{buildroot}%{_unitdir}
install -p -m 644 utils/cups-browsed.service %{buildroot}%{_unitdir}

# Don't ship foomatic-rip
rm -f %{buildroot}/usr/lib/cups/filter/foomatic-rip
rm -f %{buildroot}%{_mandir}/man1/foomatic-rip.1*

%check
#make check

%post
%_post_service cups-browsed

# Initial installation
if [ $1 -eq 1 ] ; then
    IN=%{_sysconfdir}/cups/cupsd.conf
    OUT=%{_sysconfdir}/cups/cups-browsed.conf
    keyword=BrowsePoll

    # We can remove this after few releases, it's just for the introduction of cups-browsed.
    if [ -f "$OUT" ]; then
        echo -e "\n# NOTE: This file is not part of CUPS. You need to start&enable cups-browsed service." >> "$OUT"
    fi

    # move BrowsePoll from cupsd.conf to cups-browsed.conf
    if [ -f "$IN" ] && grep -iq ^$keyword "$IN"; then
        if ! grep -iq ^$keyword "$OUT"; then
            (cat >> "$OUT" <<EOF

# Settings automatically moved from cupsd.conf by RPM package:
EOF
            ) || :
            (grep -i ^$keyword "$IN" >> "$OUT") || :
            #systemctl enable cups-browsed.service >/dev/null 2>&1 || :
        fi
        sed -i -e "s,^$keyword,#$keyword directive moved to cups-browsed.conf\n#$keyword,i" "$IN" || :
    fi
fi

%preun
%_preun_service cups-browsed

%postun
%_postun_service cups-browsed

%files
%doc __doc/README __doc/AUTHORS __doc/NEWS
%config(noreplace) %{_sysconfdir}/cups/cups-browsed.conf
%config(noreplace) %{_sysconfdir}/fonts/conf.d/99pdftoopvp.conf
%attr(0755,root,root) /usr/lib/cups/filter/*
%attr(0755,root,root) /usr/lib/cups/backend/parallel
# Serial backend needs to run as root (bug #212577#c4).
%attr(0700,root,root) /usr/lib/cups/backend/serial
%{_datadir}/cups/banners
%{_datadir}/cups/charsets
%{_datadir}/cups/data/*
# this needs to be in the main package because of cupsfilters.drv
%{_datadir}/cups/ppdc/pcl.h
%{_datadir}/cups/drv/cupsfilters.drv
%{_datadir}/cups/mime/cupsfilters.types
%{_datadir}/cups/mime/cupsfilters.convs
%{_datadir}/ppd/cupsfilters
%{_sbindir}/cups-browsed
%{_unitdir}/cups-browsed.service
%{_mandir}/man8/cups-browsed.8.*
%{_mandir}/man5/cups-browsed.conf.5.*

%files -n %libname
%doc __doc/COPYING fontembed/README
%{_libdir}/libcupsfilters.so.*
%{_libdir}/libfontembed.so.*

%files -n %develname
%{_includedir}/cupsfilters
%{_includedir}/fontembed
%{_datadir}/cups/ppdc/escp.h
%{_libdir}/pkgconfig/libcupsfilters.pc
%{_libdir}/pkgconfig/libfontembed.pc
%{_libdir}/libcupsfilters.so
%{_libdir}/libfontembed.so



%changelog
* Sat Jul 04 2015 luigiwalser <luigiwalser> 1.0.53-1.2.mga4
+ Revision: 850605
- add upstream patches to fix CVE-2015-3258 and CVE-2015-3279
- rediff upstream patch to fix security issue (upstream bug#1265, mga#15424)
- 1.0.53 (fix security issues mga#13273)
- add patch from fedora to fix CVE-2014-2707
- add patch from ubuntu to fix CVE-2013-647[3-6]

  + tv <tv>
    - fix printing: configure needs /bin/gs (mga#11684)

* Tue Nov 19 2013 tv <tv> 1.0.41-3.mga4
+ Revision: 551952
- adjust filter costs so application/vnd.adobe-read-postscript input
  doesn't go via pstotiff (rhbz#1008166)

* Tue Nov 19 2013 tv <tv> 1.0.41-2.mga4
+ Revision: 551865
- fix memory leaks in cups-browsed (rhbz#1027317)
- include dbus so that colord support works (rhbz#1026928)

* Wed Oct 30 2013 tv <tv> 1.0.41-1.mga4
+ Revision: 548025
- new release

* Tue Oct 22 2013 umeabot <umeabot> 1.0.40-3.mga4
+ Revision: 542055
- Mageia 4 Mass Rebuild

* Mon Oct 14 2013 tv <tv> 1.0.40-2.mga4
+ Revision: 496793
- fix PDF landscape printing (rhbz#768811)

* Fri Oct 11 2013 tv <tv> 1.0.40-1.mga4
+ Revision: 495218
- new release
- use new "hybrid" pdftops renderer

* Thu Oct 03 2013 tv <tv> 1.0.39-1.mga4
+ Revision: 490971
- new release

* Thu Oct 03 2013 tv <tv> 1.0.38-2.mga4
+ Revision: 490877
- sync with FC:
  o Use IPP notifications for BrowsePoll when possible (rhbz#975241)
  o Fixes for some printf-type format mismatches (rhbz#1014093)
- patch 1: fix landscape printing for PDFs (bug rhbz#768811)

* Thu Sep 12 2013 tv <tv> 1.0.38-1.mga4
+ Revision: 478016
- new release

* Sat Aug 31 2013 tv <tv> 1.0.37-2.mga4
+ Revision: 473751
- conflicts with older ghostscript-common for upgrade

* Fri Aug 30 2013 tv <tv> 1.0.37-1.mga4
+ Revision: 473432
- disable test suite
- new release
- run make check
- new release

* Wed Jul 31 2013 fwang <fwang> 1.0.35-5.mga4
+ Revision: 461346
- rebuild for new poppler

* Sat Jul 27 2013 tv <tv> 1.0.35-4.mga4
+ Revision: 458740
- requires cups-filesystem instead of cups

* Sat Jul 27 2013 tv <tv> 1.0.35-3.mga4
+ Revision: 458736
- sync with FC:
  o added support for page-label (rhz#987515)
  o add cups-browsed(8) and cups-browsed.conf(5)
  o don't reverse lookup IP address in URI (rhz#975822)

* Sat Jul 20 2013 fwang <fwang> 1.0.35-2.mga4
+ Revision: 456552
- more patch
- more patch
- add include
- update format
- try fix building with recent poppler
- rebuild for new poppler

  + tv <tv>
    - fix URL

* Sat Jun 29 2013 tv <tv> 1.0.35-1.mga4
+ Revision: 448307
- new release

* Thu Jun 20 2013 tv <tv> 1.0.34-8.mga4
+ Revision: 445204
- fix the note we add in cups-browsed.conf

* Thu Jun 13 2013 tv <tv> 1.0.34-7.mga4
+ Revision: 442559
- use our services macros rather than FC ones)

* Thu Jun 13 2013 tv <tv> 1.0.34-6.mga4
+ Revision: 442544
- prevent %%systemd_(pre|post)un to fail (ignoring status)

* Thu Jun 13 2013 tv <tv> 1.0.34-5.mga4
+ Revision: 442524
- obsolete php-cups as it has been picked by cups-filters but is broken
- cupsfilters.drv needs ppdc/pcl.h
- pstopdf requires bc
- mem leaks fixes from FC

* Tue Jun 04 2013 fwang <fwang> 1.0.34-4.mga4
+ Revision: 437124
- fix conflicts

* Tue Jun 04 2013 tv <tv> 1.0.34-3.mga4
+ Revision: 437104
- conflicts with older cups

* Tue Jun 04 2013 fwang <fwang> 1.0.34-2.mga4
+ Revision: 437054
- update requires

* Wed May 29 2013 tv <tv> 1.0.34-1.mga4
+ Revision: 430294
- imported package cups-filters

